========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/octavia-lib.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

===========
octavia-lib
===========

.. image:: https://img.shields.io/pypi/v/octavia-lib.svg
    :target: https://pypi.org/project/octavia-lib/
    :alt: Latest Version

A library to support Octavia provider drivers.

This python module provides a python library for Octavia provider driver
developers.

See the provider driver development guide for more information:

    https://docs.openstack.org/octavia/latest/contributor/guides/providers.html

Octavia-lib is distributed under the terms of the Apache License, Version 2.0.
The full terms and conditions of this license are detailed in the LICENSE file.

* Free software: Apache license
* Documentation: https://docs.openstack.org/octavia-lib/latest
* Source: https://git.openstack.org/cgit/openstack/octavia-lib
* Bugs: https://storyboard.openstack.org/#!/project/openstack/octavia-lib
